(*

MATH/ibpT1.m

File prepared for CAPP-2007 by R. Harlander.

Generates the IBP identities for the massless T1 topology.
They can be used as input for AIR (see AIR/input_topT1.map).

Usage: apply[proc[diffl1],T1[n1,n2,n3,n4,n5]] /. npmrep

*)
    
int = (1/(k^(2*n[2])*l^(2*n[1])*(-k + l)^(2*n[5])
     *(k - q)^(2*n[3])*(l - q)^(2*n[4])));

diffl1 = D+Expand[Expand[D[int,l]*(l)]/int];
diffl2 = Expand[Expand[D[int,l]*(q)]/int];
diffl3 = Expand[Expand[D[int,l]*(k)]/int];

diffk1 = Expand[Expand[D[int,k]*(l)]/int];
diffk2 = Expand[Expand[D[int,k]*(q)]/int];
diffk3 = D+Expand[Expand[D[int,k]*(k)]/int];

proc[expr_] :=
    (
     op1 = Expand[expr /. 
		  {1/(l-k) -> (l-k)*P[5], 1/(l-q) -> (l-q)*P[4],
		   1/(k-q) -> (k-q)*P[3], 1/l -> l*P[1], 1/k -> k*P[2]}];
     
     op2 = Expand[op1 /. {k*l -> 1/2*(-M[5]+M[1]+M[2]),
			  q*l -> 1/2*(-M[4]+M[1]+q^2),
			  k*q -> 1/2*(-M[3]+M[2]+q^2),
			  l^2 -> M[1], k^2 -> M[2]}];
     
     op3 = op2 /. {P[1]*M[1] -> 1,P[2]*M[2] -> 1,P[3]*M[3] -> 1,
		   P[4]*M[4] -> 1,P[5]*M[5] -> 1};

     Return[op3]);

apply[op_,expr_] := 
    (
     (* 
     usage:  apply[proc[diffl1],T1[4,2,3,1,2]] or
             apply[proc[diffl1],T1[n1,n2,n3,n4,n5]]
     *)
     op3 = op;
     integral = expr;
     redint = (Expand[op3*integral] //. 
	       {P[1]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1+1,n2,n3,n4,n5],
		P[2]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1,n2+1,n3,n4,n5],
		P[3]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1,n2,n3+1,n4,n5],
		P[4]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1,n2,n3,n4+1,n5],
		P[5]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1,n2,n3,n4,n5+1],
		M[1]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1-1,n2,n3,n4,n5],
		M[2]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1,n2-1,n3,n4,n5],
		M[3]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1,n2,n3-1,n4,n5],
		M[4]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1,n2,n3,n4-1,n5],
		M[5]*T1[n1_,n2_,n3_,n4_,n5_] -> T1[n1,n2,n3,n4,n5-1]});
     Return[redint];
     );

npmrep = {n[1] -> n1,n[2] -> n2,n[3] -> n3,n[4] -> n4,n[5] -> n5,
	  P[1] -> P1,P[2] -> P2,P[3] -> P3,P[4] -> P4,P[5] -> P5,
	  M[1] -> M1,M[2] -> M2,M[3] -> M3,M[4] -> M4,M[5] -> M5};

(* End of ipbT1.m *)
